Apium
============

.. image:: https://img.shields.io/travis/cryporchild/apium/master.png
    :alt: Build status
    :target: https://travis-ci.org/cryporchild/apium/

.. image:: https://codecov.io/github/cryporchild/apium/master.svg
    :alt: Code coverage
    :target: https://codecov.io/github/cryporchild/apium?branch=master

.. image:: https://img.shields.io/pypi/l/apium.svg
    :alt: LGPLv3+ license
    :target: https://opensource.org/licenses/lgpl-3.0.html

.. image:: https://img.shields.io/pypi/wheel/apium.svg
    :alt: Celery can be installed via wheel
    :target: http://pypi.python.org/pypi/apium/

.. image:: https://img.shields.io/pypi/pyversions/apium.svg
    :alt: Supported Python versions.
    :target: http://pypi.python.org/pypi/apium/

.. image:: https://img.shields.io/pypi/v/apium.png
    :alt: Pypi link
    :target: https://pypi.python.org/pypi/apium/

.. image:: https://img.shields.io/pypi/status/apium.svg
    :alt: Project status
    :target: https://pypi.python.org/pypi/apium/
